import { ResultAsync, Result } from "neverthrow";
import { Subject } from "rxjs";
import { Balances } from "../Balances";
import { BigNumberString } from "../BigNumberString";
import { ControlClaim } from "../ControlClaim";
import { AcceptPaymentError, BalancesUnavailableError, BlockchainUnavailableError, InsufficientBalanceError, LogicalError, PersistenceError, RouterChannelUnknownError, VectorError, GatewayValidationError, GatewayConnectorError, InvalidParametersError, ProxyError, GatewayAuthorizationDeniedError, MessagingError } from "../errors";
import { EthereumAddress } from "../EthereumAddress";
import { HypernetLink } from "../HypernetLink";
import { GatewayUrl } from "../GatewayUrl";
import { Payment } from "../Payment";
import { PaymentId } from "../PaymentId";
import { PublicIdentifier } from "../PublicIdentifier";
import { PullPayment } from "../PullPayment";
import { PushPayment } from "../PushPayment";
import { Signature } from "../Signature";
/**
 * HypernetCore is a single instance of the Hypernet Protocol, representing a single
 * user account. The user can be /both/ a consumer and a provider.
 */
export interface IHypernetCore {
    initialized(): Result<boolean, never>;
    waitInitialized(): ResultAsync<void, never>;
    /**
     * Probably can be removed, but leaving as a reminder in case we need to solve
     * the multiple-instance-of-Hypernet-core issue
     */
    inControl(): Result<boolean, never>;
    /**
     * This returns the linked Ethereum accounts via your installed wallet (ie: Metamask)
     */
    getEthereumAccounts(): ResultAsync<EthereumAddress[], BlockchainUnavailableError>;
    /**
     * This must be called before most other calls; it is used to specify what account addres
     * hypernet core will be representing.
     * @param account The address that says who this instance of HypernetCore is representing.
     */
    initialize(account: EthereumAddress): ResultAsync<void, LogicalError | MessagingError>;
    /**
     * Gets the public id of the Hypernet Core user account. If the core is not initialized,
     * it will throw an error
     * @dev currently this matches the Vector pubId
     */
    getPublicIdentifier(): ResultAsync<PublicIdentifier, never | ProxyError>;
    /**
     * This function will load HypernetCore with funds. It should be called for each type of asset you want to use.
     * Can be called by either party (provider or consumer); internally, deposits into the router channel.
     * @param assetAddress The Ethereum address of the token you want to deposit. These can be ETH, HyperToken, Dai, or any othe supported payment token.
     * @param amount The amount of funds (in wei) that you are depositing
     * @dev this creates a transaction on the blockchain!
     */
    depositFunds(assetAddress: EthereumAddress, amount: BigNumberString): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    /**
     * This function will withdraw funds from Hypernet core into a specified Ethereum address.
     * @param assetAddress
     * @param amount
     * @param destinationAddress
     */
    withdrawFunds(assetAddress: EthereumAddress, amount: BigNumberString, destinationAddress: EthereumAddress): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    /**
     * Returns the balance account, including funds within
     * the general channel, and funds locked inside transfers within the channel.
     */
    getBalances(): ResultAsync<Balances, BalancesUnavailableError>;
    /**
     * Returns all Hypernet Ledger for the user
     */
    getLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | VectorError | Error>;
    /**
     * Returns all active Hypernet Ledgers for the user
     * An active link contains an incomplete/non-finalized transfer.
     */
    getActiveLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | VectorError | Error>;
    /**
     * Returns the Hypernet Ledger for the user with the specified counterparty
     */
    getLinkByCounterparty(counterPartyAccount: PublicIdentifier): Promise<HypernetLink>;
    /**
     * For a specified payment, puts up stake to accept the payment
     * @param paymentId the payment ID to accept funds
     */
    acceptOffers(paymentIds: PaymentId[]): ResultAsync<Result<Payment, AcceptPaymentError>[], InsufficientBalanceError | AcceptPaymentError>;
    /**
     * Pulls an incremental amount from an authorized payment
     * @param paymentId: The authorized payment ID to pull from.
     * @param amount: The amount to pull. The token type has already been baked in.
     */
    pullFunds(paymentId: PaymentId, amount: BigNumberString): ResultAsync<Payment, RouterChannelUnknownError | VectorError | Error>;
    /**
     * Finalized an authorized payment with the final payment amount.
     * @param paymentId the payment ID to finalize
     * @param finalAmount the total payment amount to pull
     */
    finalizePullPayment(paymentId: PaymentId, finalAmount: BigNumberString): Promise<HypernetLink>;
    /**
     * Only used for development purposes!
     * @param amount
     */
    mintTestToken(amount: BigNumberString): ResultAsync<void, BlockchainUnavailableError>;
    authorizeGateway(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayValidationError>;
    deauthorizeGateway(gatewayUrl: GatewayUrl): ResultAsync<void, PersistenceError | ProxyError | GatewayAuthorizationDeniedError>;
    getAuthorizedGateways(): ResultAsync<Map<GatewayUrl, Signature>, PersistenceError>;
    getAuthorizedGatewaysConnectorsStatus(): ResultAsync<Map<GatewayUrl, boolean>, PersistenceError>;
    closeGatewayIFrame(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayConnectorError>;
    displayGatewayIFrame(gatewayUrl: GatewayUrl): ResultAsync<void, GatewayConnectorError>;
    providePrivateCredentials(privateKey: string | null, mnemonic: string | null): ResultAsync<void, InvalidParametersError>;
    /**
     * Observables for seeing what's going on
     */
    onControlClaimed: Subject<ControlClaim>;
    onControlYielded: Subject<ControlClaim>;
    onPushPaymentSent: Subject<PushPayment>;
    onPullPaymentSent: Subject<PullPayment>;
    onPushPaymentUpdated: Subject<PushPayment>;
    onPullPaymentUpdated: Subject<PullPayment>;
    onPushPaymentReceived: Subject<PushPayment>;
    onPullPaymentReceived: Subject<PullPayment>;
    onPushPaymentDelayed: Subject<PushPayment>;
    onPullPaymentDelayed: Subject<PullPayment>;
    onBalancesChanged: Subject<Balances>;
    onDeStorageAuthenticationStarted: Subject<void>;
    onDeStorageAuthenticationSucceeded: Subject<void>;
    onDeStorageAuthenticationFailed: Subject<void>;
    onGatewayAuthorized: Subject<GatewayUrl>;
    onGatewayDeauthorizationStarted: Subject<GatewayUrl>;
    onAuthorizedGatewayUpdated: Subject<GatewayUrl>;
    onAuthorizedGatewayActivationFailed: Subject<GatewayUrl>;
    onGatewayIFrameDisplayRequested: Subject<GatewayUrl>;
    onGatewayIFrameCloseRequested: Subject<GatewayUrl>;
    onInitializationRequired: Subject<void>;
    onPrivateCredentialsRequested: Subject<void>;
}
export declare const IHypernetCoreType: unique symbol;
//# sourceMappingURL=IHypernetCore.d.ts.map